==> openGion6.9.7.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE54S.sql <==
/****************************************************************************/
/* GE54 ( 帳票定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/03/29 14:26:21                                            */
/****************************************************************************/

CREATE TABLE GE54 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID           */
 , LISTID           VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID           */
 , LISTNAME         VARCHAR ( 100 )                                     /*  30 帳票名称         */
 , MODELDIR         VARCHAR ( 100 )                 NOT NULL            /*  40 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        VARCHAR (  20 )                 NOT NULL            /*  50 雛型ﾌｧｲﾙ名       */
 , FGCUT            VARCHAR (   1 )                                     /*  60 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , HSQL             TEXT                                                /*  70 ﾍｯﾀﾞｰSQL         */
 , FSQL             TEXT                                                /*  80 ﾌｯﾀｰSQL          */
 , BSQL             TEXT                                                /*  90 ﾎﾞﾃﾞｨSQL         */
 , COMMENTS         TEXT                                                /* 100 ｺﾒﾝﾄ             */
 , FGLOCAL          VARCHAR (   1 )     DEFAULT '0' NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , FGDIRECT         VARCHAR (   1 )     DEFAULT '0' NOT NULL            /* 120 ﾀﾞｲﾚｸﾄ           */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /* 130 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         VARCHAR (  20 )                                     /* 140 設変番号         */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            VARCHAR (  14 )                                     /* 820 登録日時         */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG           */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG         */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成社員         */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時         */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG           */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG         */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者           */
);

==> openGion7.0.2.3_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE54S.sql <==
/****************************************************************************/
/* GE54 ( 帳票定義ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE54 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID           */
 , LISTID           VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID           */
 , LISTNAME         VARCHAR ( 100 )                                     /*  30 帳票名称         */
 , MODELDIR         VARCHAR ( 100 )                 NOT NULL            /*  40 雛型ﾌｧｲﾙDIR      */
 , MODELFILE        VARCHAR (  20 )                 NOT NULL            /*  50 雛型ﾌｧｲﾙ名       */
 , FGCUT            VARCHAR (   1 )                                     /*  60 ﾍﾟｰｼﾞｴﾝﾄﾞｶｯﾄﾌﾗｸﾞ */
 , HSQL             TEXT                                                /*  70 ﾍｯﾀﾞｰSQL         */
 , FSQL             TEXT                                                /*  80 ﾌｯﾀｰSQL          */
 , BSQL             TEXT                                                /*  90 ﾎﾞﾃﾞｨSQL         */
 , COMMENTS         TEXT                                                /* 100 ｺﾒﾝﾄ             */
 , FGLOCAL          VARCHAR (   1 )     DEFAULT '0' NOT NULL            /* 110 ﾛｰｶﾙﾘｿｰｽ         */
 , FGDIRECT         VARCHAR (   1 )     DEFAULT '0' NOT NULL            /* 120 ﾀﾞｲﾚｸﾄ           */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /* 130 ﾘﾘｰｽﾉｰﾄ          */
 , RDC_CODE         VARCHAR (  20 )                                     /* 140 設変番号         */
 , OPTIONS          TEXT                                                /* 150 オプション       */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET            VARCHAR (  14 )                                     /* 820 登録日時         */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG           */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG         */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成者           */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時         */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG           */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG         */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者           */
);
